@@ -32,7 +32,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = sprintf '%s', q$Revision: 1.7 $ =~ /Revision:\s+(\S+)\s+/ ;
+our $VERSION = sprintf '%s', q$Revision: 1.8 $ =~ /Revision:\s+(\S+)\s+/ ;
 
 
 my $stdin = '<STDIN>';
@@ -42,12 +42,12 @@ our @attr = qw
    dbi_connect_method
    Warn
 
-   !Active (boolean, read-only) 
-   !Executed
-   !Kids
-   !ActiveKids
-   !CachedKids
-   !CompatMode
+   _Active
+   _Executed
+   _Kids
+   _ActiveKids
+   _CachedKids
+   _CompatMode
 
    InactiveDestroy
    PrintWarn
@@ -56,7 +56,7 @@ our @attr = qw
    HandleError
    HandleSetErr
 
-   !ErrCount
+   _ErrCount
 
    ShowErrorStatement
    TraceLevel
@@ -68,18 +68,18 @@ our @attr = qw
    TaintOut
    Taint
    Profile
-   !should-add-support-for-private_your_module_name_*
+   _should-add-support-for-private_your_module_name_*
 
 
    AutoCommit
 
-   !Driver
-   !Name
-   !Statement
+   _Driver
+   _Name
+   _Statement
 
    RowCacheSize
 
-   !Username
+   _Username
   );
 
 our @valid_directives = ( qw(User Pass DSN), @attr ) ;
